@@ -65,7 +65,7 @@ public:
 
     /** Get item bounding rect. Default implementation returns
      *  value set by setBoundingRect function */
-    QRectF boundingRect() const { return _boundingRect; }
+    QRectF boundingRect() const Q_DECL_OVERRIDE { return _boundingRect; }
 
     /** Set current bounding rect. Should be called by subclass. */
     void setBoundingRect(const QRectF& rect) { _boundingRect = rect; }
@@ -88,7 +88,7 @@ public:
 
     /** Virtual function to paint the item. Default implementation
      *  draws boundingRect() in grey color */
-    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
+    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) Q_DECL_OVERRIDE;
 
     /** Get item highlight state */
     bool isItemHighlighted() { return _isHighlighted; }
@@ -146,7 +146,7 @@ protected:
     void setExclusiveMovingMessage(const QString& message) { _exclusiveMovingMessage = message; }
 
     /** Called when graphicsitem is changed */
-    QVariant itemChange(GraphicsItemChange change, const QVariant& value);
+    QVariant itemChange(GraphicsItemChange change, const QVariant& value) Q_DECL_OVERRIDE;
 
     /** Get vertex handler enabled status */
     bool isOnHoverHandlerEnabled() const { return _onHoverHandlerEnabled; }
@@ -178,15 +178,15 @@ protected:
     QPointer<OnHoverHandlerGraphicsItem> _onHoverHandler;
     bool _onHoverHandlerTimer;
 
-    void mousePressEvent(QGraphicsSceneMouseEvent* event);
-    void mouseMoveEvent(QGraphicsSceneMouseEvent* event);
-    void mouseReleaseEvent(QGraphicsSceneMouseEvent* event);
+    void mousePressEvent(QGraphicsSceneMouseEvent* event) Q_DECL_OVERRIDE;
+    void mouseMoveEvent(QGraphicsSceneMouseEvent* event) Q_DECL_OVERRIDE;
+    void mouseReleaseEvent(QGraphicsSceneMouseEvent* event) Q_DECL_OVERRIDE;
 
-    void hoverEnterEvent(QGraphicsSceneHoverEvent* event);
-    void hoverMoveEvent(QGraphicsSceneHoverEvent* event);
-    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event);
+    void hoverEnterEvent(QGraphicsSceneHoverEvent* event) Q_DECL_OVERRIDE;
+    void hoverMoveEvent(QGraphicsSceneHoverEvent* event) Q_DECL_OVERRIDE;
+    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event) Q_DECL_OVERRIDE;
 
-    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event);
+    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event) Q_DECL_OVERRIDE;
 
 protected:
     static const QColor SELECTION_COLOR;     ///< Default color for selection rectangle
@@ -228,10 +228,10 @@ public:
                         QGraphicsItem* parent, const StepCore::MetaProperty* property,
                         const StepCore::MetaProperty* positionProperty = NULL);
 
-    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
+    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) Q_DECL_OVERRIDE;
 
-    void viewScaleChanged();
-    void worldDataChanged(bool);
+    void viewScaleChanged() Q_DECL_OVERRIDE;
+    void worldDataChanged(bool) Q_DECL_OVERRIDE;
 
 protected:
     /** Virtual function which is called to get current vector value.
@@ -241,8 +241,8 @@ protected:
      *  Default implementation sets property = value - positionProperty */
     virtual void setValue(const StepCore::Vector2d& value);
 
-    void mouseSetPos(const QPointF& pos, const QPointF& diff, MovingState movingState);
-    QVariant itemChange(GraphicsItemChange change, const QVariant& value);
+    void mouseSetPos(const QPointF& pos, const QPointF& diff, MovingState movingState) Q_DECL_OVERRIDE;
+    QVariant itemChange(GraphicsItemChange change, const QVariant& value) Q_DECL_OVERRIDE;
     const StepCore::MetaProperty* _property;
     const StepCore::MetaProperty* _positionProperty;
 };
@@ -266,10 +266,10 @@ public:
                         QGraphicsItem* parent, double radius, const StepCore::MetaProperty* property,
                         const StepCore::MetaProperty* positionProperty = NULL);
 
-    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
+    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) Q_DECL_OVERRIDE;
 
-    void viewScaleChanged();
-    void worldDataChanged(bool);
+    void viewScaleChanged() Q_DECL_OVERRIDE;
+    void worldDataChanged(bool) Q_DECL_OVERRIDE;
 
 protected:
     /** Virtual function which is called to get current vector value.
@@ -279,9 +279,9 @@ protected:
      *  Default implementation sets the value pointed by property */
     virtual void setValue(double value);
 
-    QVariant itemChange(GraphicsItemChange change, const QVariant& value);
-    void mouseMoveEvent(QGraphicsSceneMouseEvent *event);
-    void mouseReleaseEvent(QGraphicsSceneMouseEvent *event);
+    QVariant itemChange(GraphicsItemChange change, const QVariant& value) Q_DECL_OVERRIDE;
+    void mouseMoveEvent(QGraphicsSceneMouseEvent *event) Q_DECL_OVERRIDE;
+    void mouseReleaseEvent(QGraphicsSceneMouseEvent *event) Q_DECL_OVERRIDE;
     const StepCore::MetaProperty* _property;
     const StepCore::MetaProperty* _positionProperty;
     double _radius;
@@ -310,8 +310,8 @@ public:
     static const StepCore::Vector2d scorners[4];
 
 protected:
-    void hoverEnterEvent(QGraphicsSceneHoverEvent* event);
-    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event);
+    void hoverEnterEvent(QGraphicsSceneHoverEvent* event) Q_DECL_OVERRIDE;
+    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event) Q_DECL_OVERRIDE;
 
     int _vertexNum;
     QTimer* _deleteTimer;
